@@ -13,8 +13,8 @@ from .show_commands import ShowKubectlCommands
 from .show_processes import ShowProcesses
 from .show_repairs import ShowRepairs
 from .show_storage import ShowStorage
-from .show_version import ShowVersion
-from adam.repl_state import ReplState, RequiredState
+from .show_adam import ShowAdam
+from adam.repl_state import ReplState
 from adam.utils import lines_to_tabular, log, log2
 
 class Show(Command):
@@ -32,16 +32,11 @@ class Show(Command):
     def command(self):
         return Show.COMMAND
 
-    def required(self):
-        return RequiredState.CLUSTER_OR_POD
-
     def run(self, cmd: str, state: ReplState):
         if not(args := self.args(cmd)):
             return super().run(cmd, state)
 
         state, args = self.apply_state(args, state)
-        if state.in_repl and not self.validate_state(state):
-            return state
 
         if state.in_repl:
             log(lines_to_tabular([c.help(ReplState()) for c in Show.cmd_list()], separator='\t'))
@@ -56,7 +51,7 @@ class Show(Command):
 
     def cmd_list():
         return [ShowAppActions(), ShowAppId(), ShowAppQueues(), ShowLogin(), ShowKubectlCommands(), ShowParams(), ShowProcesses(), ShowRepairs(),
-                ShowStorage(), ShowVersion(), ShowCassandraStatus(), ShowCassandraVersion()]
+                ShowStorage(), ShowAdam(), ShowCassandraStatus(), ShowCassandraVersion()]
 
     def completion(self, state: ReplState):
         return super().completion(state)
